@@ -19,8 +19,6 @@
 #' ## Bland Altman 1995 data
 #' rmcorr(Subject, PacO2, pH, bland1995)
 #' @export
-
-
 rmcorr <- function(participant, measure1, measure2, dataset, 
                    CIs = c("analytic", "bootstrap"), 
                    nreps = 100, bstrap.out = F) {
@@ -33,7 +31,7 @@ rmcorr <- function(participant, measure1, measure2, dataset,
     if (!is.factor(Participant)) 
     {
         Participant <- factor(Participant)
-        warning("Participant coerced into a factor")
+        warning(paste("'", args$participant, "' coerced into a factor", sep = ""))
     }
     
     Measure1 <- eval(args$measure1, dataset)
@@ -41,6 +39,12 @@ rmcorr <- function(participant, measure1, measure2, dataset,
     if (!is.numeric(Measure1) || !is.numeric(Measure2))
         stop("'Measure 1' and 'Measure 2' must be numeric")
     
+    #check for missing values
+    newdat <- stats::na.omit(data.frame(Participant, Measure1, Measure2))
+    Participant <- newdat$Participant
+    Measure1 <- newdat$Measure1
+    Measure2 <- newdat$Measure2
+    
     CIs <- match.arg(CIs)
     
     lmmodel <- stats::lm(Measure2 ~ Participant + Measure1)
@@ -108,7 +112,7 @@ rmcorr <- function(participant, measure1, measure2, dataset,
 } 
 
 
-#' Calculate the repeated measures correlation coefficient.
+#' Print the results of a repeated measures correlation
 #' 
 #' @param x An object of class "rmc", a result of a call to rmcorr.
 #' @param ... additional arguments to \code{\link[base]{print}}.
